@@ -20,7 +20,7 @@ class NodeVisitor:
         self.no_children = {'operator', 'reservedword', 'pipe', 'parameter', 'tilde', 'heredoc'}
         self.parts_children = {'list', 'pipeline', 'if', 'for', 'while', 'until', 'command', 'function', 'word', 'assignment'}
         self.command_children = {'commandsubstitution', 'processsubstitution'}
-        self.passable_nodes = {'command', 'list', 'compound', 'for', 'parameter', 'function', 'pipeline'}
+        self.passable_nodes = {'command', 'list', 'compound', 'for', 'parameter', 'function', 'pipeline', 'if'}
         self.list_children = {}
         self.contains_variable_text = {'word', 'assignment'}
 
